@@ -190,6 +190,7 @@ namespace gnote {
         break;
       case Format::CURRENT_YEAR:
         /* TRANSLATORS: date in current year. */
+        /* xgettext:no-c-format */
         pretty_str = sharp::date_time_to_string(date, _("%b %d")); // "MMMM d"
         goto DATE_AND_TIME;
       case Format::OTHER_YEAR:
@@ -302,6 +303,8 @@ namespace gnote {
         label->set_justify(Gtk::Justification::LEFT);
         label->set_halign(Gtk::Align::START);
         label->set_valign(Gtk::Align::CENTER);
+        label->set_wrap(TRUE);
+        label->set_max_width_chars(60);
         label_vbox->attach(*label, 0, label_vbox_row++, 1, 1);
       }
       
